@@ -1,6 +1,7 @@
 import csv
 import json
 import logging
+import time
 
 import ccxt
 import pandas as pd
@@ -133,7 +134,7 @@ class LoadTradeKline(LoadData):
                 } for trade in trades]
 
                 self.write_data(result)
-                time.sleep(int(self.exchange.rateLimit / 1000))
+                #time.sleep(int(self.exchange.rateLimit / 1000))
             except ccxt.NetworkError as e:
                 print(type(e).__name__, str(e))
                 self.exchange.sleep(1000)
